Document

WORKIVA INC.
a Delaware corporation
BYLAWS
As Amended October 28, 2022January 9, 2023

Table of Contents

|  | Page
ARTICLE I: | STOCKHOLDERS | 1
SECTION 1.1 - | Place of Meeting; Meetings by Remote Communication | 1
SECTION 1.2 - | Annual Meeting | 1
SECTION 1.3 - | Special Meeting | 1
SECTION 1.4 - | Notice of Stockholders’ Meetings | 1
SECTION 1.5 - | Manner of Giving Notice; Affidavit of Notice | 2
SECTION 1.6 - | Quorum | 2
SECTION 1.7 - | Adjournments | 2
SECTION 1.8 - | Conduct of Business | 2
SECTION 1.9 - | Voting | 3
SECTION 1.10 - | Proxies | 3
SECTION 1.11 - | Record Date | 3
SECTION 1.12 - | Advance Notice of Stockholder Nominations and Proposals | 4
SECTION 1.13 - | Remote Communication | 9
SECTION 1.14 - | Inspectors of Elections; Opening and Closing the Polls | 9
SECTION 1.15 - | Conduct of Business | 9
SECTION 1.16 - | Stock List | 10
ARTICLE II: | DIRECTORS | 10
SECTION 2.1 - | Number of Directors | 10
SECTION 2.2 - | Election, Qualification and Term of Office of Directors | 10
SECTION 2.3 - | Regular Meetings | 11
SECTION 2.4 - | Special Meetings | 11
SECTION 2.5 - | Remote Meetings Permitted | 11
SECTION 2.6 - | Quorum | 11
SECTION 2.7 - | Board Action By Written Consent Without A Meeting | 11
SECTION 2.8 - | Powers | 12
SECTION 2.9 - | Fees and Compensation of Directors | 12
ARTICLE III: | COMMITTEES | 12
SECTION 3.1 - | Committees of Directors | 12
SECTION 3.2 - | Committee Minutes | 12
SECTION 3.3 - | Meetings and Actions of Committees | 12
ARTICLE IV: | OFFICERS | 12

i

Table of Contents

SECTION 4.1 - | Officers | 13
SECTION 4.2 - | Removal and Resignation of Officers | 13
SECTION 4.3 - | Chief Executive Officer | 13
SECTION 4.4 - | President | 13
SECTION 4.5 - | Vice Presidents | 13
SECTION 4.6 - | Secretary | 14
SECTION 4.7 - | Chief Financial Officer | 14
SECTION 4.8 - | Authority and Duties of Officers | 14
SECTION 4.9 - | Duties of Officers May be Delegated | 14
ARTICLE V: | INDEMNIFICATION OF DIRECTORS AND OTHER PARTIES | 14
SECTION 5.1 - | Indemnification of Directors and Officers | 14
SECTION 5.2 - | Indemnification of Others | 15
SECTION 5.3 - | Payment of Expenses in Advance | 15
SECTION 5.4 - | Indemnity Not Exclusive | 15
SECTION 5.5 - | Insurance | 15
SECTION 5.6 - | Conflicts | 16
SECTION 5.7 - | Right to Bring Suit | 16
SECTION 5.8 - | Amendment of Article V | 17
ARTICLE VI: | GENERAL MATTERS | 17
SECTION 6.1 - | Checks | 17
SECTION 6.2 - | Execution of Corporate Contracts and Instruments | 17
SECTION 6.3 - | Stock Certificates | 17
SECTION 6.4 - | Lost Certificates | 17
SECTION 6.5 - | Fiscal Year | 18
SECTION 6.6 - | Seal | 18
SECTION 6.7 - | Construction; Definitions | 18
SECTION 6.8 - | Severability | 18
SECTION 6.9 - | Waiver of Notice | 18
SECTION 6.10 - | Voting of Securities | 18
ARTICLE VII: | AMENDMENTS | 18
SECTION 7.1 - | Amendments | 19

i

Table of Contents
WORKIVA INC.
BYLAWS
As Amended October 28, 2022January 9, 2023
ARTICLE I: STOCKHOLDERS
Section 1.1 Place of Meeting; Meetings by Remote Communication. Meetings of stockholders of Workiva Inc. (the “Corporation”) shall be held at such place, if any, within or outside the State of Delaware, as may be designated by the Board of Directors of the Corporation (the “Board of Directors”). The Board of Directors may, in its sole discretion, determine that a meeting shall not be held at any place, but may instead be held solely by means of remote communication in accordance with Section 211(a)(2) of the General Corporation Law of the State of Delaware (the “General Corporation Law”) and Section 1.13 of these Bylaws. The Board of Directors may postpone, adjourn, reschedule or cancel any previously scheduled meeting of stockholders.
Section 1.2 Annual Meeting. The annual meeting of stockholders shall be held on such date, time and place, if any, either within or without the State of Delaware, as may be determined by resolution of the Board of Directors. At the annual meeting, directors shall be elected to succeed those whose terms expire and any other proper business may be transacted.
Section 1.3 Special Meeting. Unless otherwise provided by the Certificate of Incorporation of the Corporation (as the same may be amended and/or restated from time to time, the “Certificate of Incorporation”), special meetings of stockholders for any purpose or purposes may be called at any time by a majority of the total number of authorized directors (the “Whole Board”), the Chairman of the Board, the Chief Executive Officer (or, if a Chief Executive Officer is not then currently in office, the President), and may not be called by any other person or persons.
Section 1.4 Notice of Stockholders’ Meetings. Whenever stockholders are required or permitted to take any action at a meeting, a timely notice of the meeting, given in writing or by a form of electronic transmission consented to by the stockholder to whom the notice is given in the manner provided in Section 232 of the General Corporation Law, shall be mailed or transmitted electronically by the Corporation to each stockholder of record entitled to vote thereat as of the record date for determining stockholders entitled to receive notice of the meeting. Unless otherwise provided by law, the Certificate of Incorporation or these Bylaws, the notice of any meeting of stockholders shall be given not less than ten (10) nor more than sixty (60) days before the date of the meeting to each stockholder entitled to vote at such meeting as of the record date for determining the stockholders entitled to notice of the meeting. The notice shall specify the place, if any, date, and hour of the meeting, and the means of remote communications, if any, by which stockholders and proxy holders may be deemed present in person and vote at such meeting, and, in the case of a special meeting, the purpose or purposes for which the meeting is called.
1

Table of Contents
Section 1.5 Manner of Giving Notice; Affidavit of Notice. Written notice of any meeting of stockholders, if mailed, shall be deemed given when deposited in the United States mail, postage prepaid, directed to the stockholder at his address as it appears on the records of the Corporation. Written notice of any meeting of stockholders, if given by electronic transmission, shall be deemed given when provided in accordance with Section 232 of the DGCL. An affidavit of the Secretary or an assistant Secretary or of the transfer agent of the Corporation that the notice has been given shall, in the absence of fraud, be prima facie evidence of the facts stated therein.
Section 1.6 Quorum. The holders of a majority in voting power of the shares of capital stock of the Corporation issued and outstanding and entitled to vote at the meeting, present in person, present by means of remote communication in a manner, if any, authorized by the Board of Directors in its sole discretion, or represented by proxy, shall constitute a quorum at all meetings of the stockholders for the transaction of business except as otherwise provided by the General Corporation Law, the Certificate of Incorporation or these Bylaws; provided, however, that where a separate vote by a class or classes or series of capital stock is required by law or the Certificate of Incorporation, the holders of a majority in voting power of the shares of such class or classes or series of the capital stock of the Corporation issued and outstanding and entitled to vote on such matter, present in person, present by means of remote communication in a manner, if any, authorized by the Board in its sole discretion, or represented by proxy, shall constitute a quorum entitled to take action with respect to the vote on such matter. If a quorum is not present or represented at any meeting of the stockholders, then either (a) the chairman of the meeting or (b) the holders of a majority in voting power of the stock present or represented by proxy at the meeting and entitled to vote thereat shall have power to adjourn the meeting from time to time, without notice other than announcement at the meeting, until a quorum is present or represented. Once a quorum is established at a meeting, it shall not be broken by the subsequent withdrawal of any stockholders.
Section 1.7 Adjournments. When a meeting is adjourned to another time or place, unless these Bylaws otherwise require, notice need not be given of the adjourned meeting if the time and place, if any, thereof are announced at the meeting at which the adjournment is taken. At the adjourned meeting the Corporation may transact any business that might have been transacted at the original meeting. If the adjournment is for more than thirty (30) days, a notice shall be given to each stockholder of record entitled to vote at the meeting. If after the adjournment a new record date for determination of stockholders entitled to vote is fixed for the adjourned meeting, the Board of Directors shall fix as the record date for determining stockholders entitled to receive notice of the adjourned meeting the same or an earlier date as that fixed for determination of stockholders of record entitled to vote at the adjourned meeting, and shall give notice of the adjourned meeting to each stockholder of record entitled to vote at such adjourned meeting as of the record date so fixed for notice of such adjourned meeting.
Section 1.8 Conduct of Business. Meetings of stockholders shall be presided over by the Chairman of the Board or by such other person as the Board of Directors may designate. The chairman of any meeting of stockholders shall determine the order of business and the procedure
2

Table of Contents
at the meeting, including the manner of voting and the conduct of business. The Board of Directors may adopt by resolution such rules and regulations for the conduct of the meeting of stockholders as it deems appropriate.
Section 1.9 Voting. When a quorum is present at any meeting, except as otherwise provided by the Certificate of Incorporation, directors shall be elected by a plurality of the votes cast. Unless otherwise provided by the General Corporation Law, the Certificate of Incorporation or these Bylaws, or any other applicable rules or regulations, including the applicable rules or regulations of any stock exchange upon which the Corporation’s securities are listed, every matter (other than the election of directors) submitted to a vote of stockholders at which a quorum is present shall be decided by the affirmative vote of a majority of the votes cast for or against such matter; and, for the avoidance of doubt, neither abstentions nor broker non-votes will be counted as votes cast for or against such matter.
Section 1.10 Proxies. Each stockholder entitled to vote at a meeting of stockholders or to express consent or dissent to corporate action in writing without a meeting may authorize another person or persons to act for such stockholder by a proxy given in any manner provided by law, but no such proxy shall be voted or acted upon after three (3) years from its date, unless the proxy provides for a longer period. A proxy shall be irrevocable if it states that it is irrevocable and if, and only as long as, it is coupled with an interest sufficient in law to support an irrevocable power. A stockholder may revoke any proxy which is not irrevocable by attending the meeting and voting in person or by delivering to the Secretary of the Corporation a revocation of the proxy or a new proxy bearing a later date. Any stockholder directly or indirectly soliciting proxies from other stockholders must use a proxy card other than white, which shall be reserved for the exclusive use by the Board of Directors.
Section 1.11 Record Date.
(a) In order that the Corporation may determine the stockholders entitled to notice of any meeting of stockholders or any adjournment thereof, the Board of Directors may fix a record date, which record date shall not precede the date upon which the resolution fixing the record date is adopted by the Board of Directors, and which record date shall, unless otherwise required by law, not be more than sixty (60) nor less than ten (10) days before the date of such meeting. If the Board of Directors so fixes a date, such date shall also be the record date for determining the stockholders entitled to vote at such meeting unless the Board of Directors determines, at the time it fixes such record date, that a later date on or before the date of the meeting shall be the date for making such determination. If no record date is fixed by the Board of Directors, the record date for determining stockholders entitled to notice of or to vote at a meeting of stockholders shall be at the close of business on the day next preceding the day on which notice is given, or, if notice is waived, at the close of business on the day next preceding the day on which the meeting is held. A determination of stockholders of record entitled to notice of or to vote at a meeting of stockholders shall apply to any adjournment of the meeting; provided, however, that the Board of Directors may fix a new record date for determination of stockholders entitled to vote at the adjourned meeting, and in such case
3

Table of Contents
shall also fix as the record date for stockholders entitled to notice of such adjourned meeting the same or an earlier date as that fixed for determination of stockholders entitled to vote in accordance herewith at the adjourned meeting.
(b) In order that the Corporation may determine the stockholders entitled to receive payment of any dividend or other distribution or allotment of any rights, or entitled to exercise any rights in respect of any change, conversion or exchange of stock or for the purpose of any other lawful action, the Board of Directors may fix a record date, which record date shall not precede the date upon which the resolution fixing the record date is adopted, and which record date shall not be more than sixty (60) days prior to such action. If no such record date is fixed, the record date for determining stockholders for any such purpose shall be at the close of business on the day on which the Board of Directors adopts the resolution relating thereto.
(c) Unless otherwise restricted by the Certificate of Incorporation, in order that the Corporation may determine the stockholders entitled to express consent to corporate action in writing without a meeting, the Board of Directors may fix a record date, which record date shall not precede the date upon which the resolution fixing the record date is adopted by the Board of Directors, and which record date shall not be more than ten (10) days after the date upon which the resolution fixing the record date is adopted by the Board of Directors. If no record date for determining stockholders entitled to express consent to corporate action in writing without a meeting is fixed by the Board of Directors, (i) when no prior action of the Board of Directors is required by law, the record date for such purpose shall be the first date on which a signed written consent setting forth the action taken or proposed to be taken is delivered to the Corporation in accordance with applicable law, and (ii) if prior action by the Board of Directors is required by law, the record date for such purpose shall be at the close of business on the day on which the Board of Directors adopts the resolution taking such prior action.
Section 1.12 Advance Notice of Stockholder Nominations and Proposals.
(a) Annual Meetings of Stockholders; Timely Notice. At a meeting of the stockholders, only such nominations of persons for the election of directors and such other business shall be conducted as shall have been properly brought before the meeting. To be properly brought before an annual meeting, nominations or such other business must be: (i) specified in the notice of meeting (or any supplement thereto) given by or at the direction of the Board of Directors or any duly authorized committee thereof, (ii) otherwise properly brought before the meeting by or at the direction of the Board of Directors or any duly authorized committee thereof, or (iii) otherwise properly brought before an annual meeting by a stockholder who is a stockholder of record of the Corporation at the time such notice of meeting is delivered, who is entitled to vote at the meeting and who complies with the notice procedures set forth in this Section 1.12. In addition, any proposal of business (other than the nomination of persons for election to the Board of Directors) must be a proper matter for stockholder action. For business (including, but not limited to, director nominations) to be properly brought before an
4

Table of Contents
annual meeting by a stockholder, the stockholder or stockholders of record intending to propose the business (the “Proposing Stockholder”) must have given timely notice thereof pursuant to this Section 1.12(a) or Section 1.12(c) below, as applicable, in writing to the Secretary of the Corporation even if such matter is already the subject of any notice to the stockholders or public disclosure from the Board of Directors. To be timely, a Proposing Stockholder’s written notice shall set forth all information required under Section 1.12(b) and shall be delivered to the Secretary at the principal executive offices of the Corporation not less than 90 days nor more than 120 days prior to the first anniversary of the immediately preceding year’s annual meeting; provided, however, that in the event that no annual meeting was held in the previous year or the annual meeting is called for a date that is not within 30 days from the first anniversary of the immediately preceding year’s annual meeting date, written notice by a Proposing Stockholder in order to be timely must be received no earlier than the 120th day before the date of such annual meeting and not later than the later of the 90th day before the date of such annual meeting, as originally convened, or the close of business on the tenth day following the day on which the first public disclosure of the date of such annual meeting was made. In no event shall the public disclosure of an adjournment or postponement of an annual meeting commence a new time period (or extend any time period) for the giving of stockholder’s notice as described above.
(b) Stockholder Nominations. For the nomination of any person or persons for election to the Board of Directors, a Proposing Stockholder’s notice to the Secretary of the Corporation shall set forth (i) the name, age, business address and residence address of each nominee proposed in such notice, (ii) the principal occupation or employment of each such nominee, (iii) the number of shares of capital stock of the Corporation which are owned of record and beneficially by each such nominee (if any), (iv) such other information concerning each such nominee as would be required to be disclosed in a proxy statement soliciting proxies for the election of such nominee as a director in an election contest (even if an election contest is not involved) or that is otherwise required to be disclosed, under Section 14(a) of the Securities Exchange Act of 1934, as amended (the “Exchange Act”), and the rules and regulations promulgated thereunder, (v) the consent of the nominee to being named in any proxy materials as a nominee and to serving as a director if elected, and (vi) as to the Proposing Stockholder and the beneficial owner, if any, on whose behalf the nomination is made: (A) the name and address of the Proposing Stockholder as they appear on the Corporation's books and of any such beneficial owner, (B) the class and number of shares of the Corporation which are owned by the Proposing Stockholder (beneficially and of record) or by any such beneficial owner as of the date of the Proposing Stockholder's notice, and a representation that the Proposing Stockholder will notify the Corporation, promptly following the later of the record date or the date notice of the record date is first publicly disclosed, in writing of the class and number of such shares owned by the Proposing Stockholder (beneficially and of record) or by any such beneficial owner as of the record date for the meeting, (C) a description of any agreement, arrangement or understanding with respect to such nomination between or among the Proposing Stockholder, any such beneficial owner and any of their respective affiliates or associates, and any others (including their names)
5

Table of Contents
acting in concert with any of the foregoing, and a representation that the Proposing Stockholder will notify the Corporation, promptly following the later of the record date or the date notice of the record date is first publicly disclosed, in writing of any such agreement, arrangement or understanding in effect as of the record date for the meeting, (D) a description of any agreement, arrangement or understanding (including any derivative or short positions, profit interests, options, hedging transactions, and borrowed or loaned shares) that has been entered into as of the date of the Proposing Stockholder’s notice by, or on behalf of, the Proposing Stockholder, any such beneficial owner or any of their respective affiliates or associates, the effect or intent of which is to mitigate loss to, manage risk or benefit of share price changes for, or increase or decrease the voting power of the Proposing Stockholder, any such beneficial owner or any of their respective affiliates or associates with respect to shares of stock of the Corporation, and a representation that the Proposing Stockholder will notify the Corporation, promptly following the later of the record date or the date notice of the record date is first publicly disclosed, in writing of any such agreement, arrangement or understanding in effect as of the record date for the meeting, (E) a representation that the Proposing Stockholder is a holder of record of shares of the Corporation entitled to vote at the meeting and intends to appear in person or by proxy at the meeting to nominate the person or persons specified in the notice, (F) a representation whether the Proposing Stockholder or any such beneficial owner intends or is part of a group that intends to deliver a proxy statement and/or form of proxy and/or otherwise to solicit proxies from stockholders in support of the nomination, and (G) any other information relating to the Proposing Stockholder and any such beneficial owner required to be disclosed in a proxy statement or other filings required to be made in connection with solicitations of proxies for the election of directors in an election contest (even if an election contest is not involved) or that is otherwise required to be disclosed, under Section 14(a) of the Exchange Act and the rules and regulations promulgated thereunder. The Corporation may require any proposed nominee to furnish such other information as it may reasonably require to determine the eligibility of such proposed nominee to serve as an independent director of the Corporation or that could be material to a reasonable stockholder’s understanding of the independence, or lack thereof, of such nominee. Notwithstanding anything in the Section 1.12(a) to the contrary, in the event that the number of directors to be elected to the Board of Directors at the annual meeting is increased effective after the time period for which nominations would otherwise be due under Section 1.12(a) and there is no public announcement by the Corporation naming the nominees for the additional directorships at least one hundred (100) days prior to the first anniversary of the preceding year's annual meeting, the Proposing Stockholder’s notice required by this Section 1.12 shall also be considered timely, but only with respect to nominees for the additional directorships, if it shall be delivered to the Secretary at the principal executive offices of the Corporation not later than the close of business on the tenth day following the day on which such public announcement is first made by the Corporation.
(c) Other Stockholder Proposals. For all business other than director nominations, a Proposing Stockholder’s notice to the Secretary of the Corporation shall set forth as to each matter the Proposing Stockholder proposes to bring before the annual
6

Table of Contents
meeting: (i) a brief description of the business desired to be brought before the annual meeting, the text of the proposal or business (including the text of any resolutions proposed for consideration and in the event that such business includes a proposal to amend the Bylaws of the Corporation, the language of the proposed amendment), and the reasons for conducting such business at the annual meeting and any material interest in such business of such stockholder and beneficial owner, if any, on whose behalf the proposal is being made, (ii) any other information relating to such stockholder and any such beneficial owner required to be disclosed in a proxy statement or other filings required to be made in connection with solicitations of proxies for the proposal and pursuant to and in accordance with Section 14(a) of the Exchange Act and the rules and regulations promulgated thereunder and (iii) the information required by Section 1.12(b)(vi) above, provided that all references to a nomination in such Section shall be deemed to refer to such other business.
(d) Effect of Rule 14a-8. The foregoing notice requirements of Section 1.12(c) shall be deemed satisfied by a stockholder with respect to business other than a nomination if the stockholder has notified the Corporation of his, her or its intention to present a proposal at an annual meeting in compliance with Rule 14a-8 promulgated under the Exchange Act and such stockholder’s proposal has been included in a proxy statement that has been prepared by the Corporation to solicit proxies for such annual meeting.
(e) Special Meetings of Stockholders. Only such business shall be conducted at a special meeting of stockholders as shall have been brought before the meeting pursuant to the Corporation’s notice of meeting. Nominations of persons for election to the Board of Directors may be made at a special meeting of stockholders at which directors are to be elected pursuant to the Corporation’s notice of meeting (x) by or at the direction of the Board of Directors or any committee thereof or (y) provided that the Board of Directors has determined that directors shall be elected at such meeting, by any stockholder of the Corporation who is a stockholder of record at the time the notice provided for in this Section 1.12 is delivered to the Secretary of the Corporation, who is entitled to vote at the meeting and upon such election and who complies with the notice procedures set forth in this Section 1.12. In the event the Corporation calls a special meeting of stockholders for the purpose of electing one or more directors to the Board of Directors, any such stockholder entitled to vote in such election of directors may nominate a person or persons (as the case may be) for election to such position(s) as specified in the Corporation’s notice of meeting, if the stockholder’s notice required by this Section 1.12 shall be delivered to the Secretary at the principal executive offices of the Corporation no earlier than the close of business on the 120th day prior to such special meeting and no later than the close of business on the later of the 90th day prior to such special meeting or the tenth day following the date of public disclosure of the date of the special meeting and of the nominees proposed by the Board of Directors to be elected at such meeting. In no event shall the public disclosure of an adjournment or postponement of a special meeting commence a new time period (or extend any notice time period).
7

Table of Contents
(f) Effect of Noncompliance. Notwithstanding anything in these Bylaws to the contrary: (i) no nominations shall be made or business shall be conducted at any annual meeting except in accordance with the procedures set forth in this Section 1.12, and (ii) unless otherwise required by law, if (x) a Proposing Stockholder intending to propose business or make nominations at an annual meeting pursuant to this Section 1.12 does not timely provide the information required under this Section 1.12 to the Corporation, or (y) the Proposing Stockholder (or a qualified representative of the Proposing Stockholder) does not appear at the meeting to present the proposed business or nominations, such business or nominations shall not be considered, notwithstanding that proxies in respect of such business or nominations may have been received by the Corporation. Except as otherwise provided by law, the chairman of the meeting shall have the power and duty (I) to determine whether a nomination or any business proposed to be brought before the meeting was made or proposed, as the case may be, in accordance with the procedures set forth in this Section 1.12 and (II) if any proposed nomination or business was not made or proposed in compliance with this Section 1.12, to declare that such nomination shall be disregarded or that such proposed business shall not be transacted. Unless otherwise required by law, if any stockholder (1) provides notice pursuant to Rule 14a-19 under the Exchange Act and (2) subsequently (A) notifies the Corporation that the stockholder no longer intends to solicit proxies in support of director nominees other than the Corporation’s director nominees in accordance with Rule 14a-19, or (B) fails to comply with the requirements of Rule 14a-19, then such stockholder’s nominations shall be deemed null and void and the Corporation shall disregard any proxies or votes solicited for any nominee proposed by such stockholder.
(g) General. For purposes of this Section 1.12, to be considered a qualified representative of the Proposing Stockholder, a person must be a duly authorized officer, manager or partner of such Proposing Stockholder or must be authorized by a writing executed by such Proposing Stockholder or an electronic transmission delivered by such Proposing Stockholder to act for such Proposing Stockholder as proxy at the meeting of stockholders and such person must produce such writing or electronic transmission, or a reliable reproduction of the writing or electronic transmission, at the meeting of stockholders. For purposes of this Section 1.12, “public announcement” shall include disclosure in a press release reported by the Dow Jones News Service, Associated Press or other national news service or in a document publicly filed by the Corporation with the Securities and Exchange Commission pursuant to Section 13, 14 or 15(d) of the Exchange Act and the rules and regulations promulgated thereunder. Notwithstanding the foregoing provisions of this Section 1.12, a Proposing Stockholder shall also comply with all applicable requirements of the Exchange Act and the rules and regulations promulgated thereunder with respect to the matters set forth in this Section 1.12; provided however, that any references in these Bylaws to the Exchange Act or the rules and regulations promulgated thereunder are not intended to and shall not limit any requirements applicable to nominations or proposals as to any other business to be considered pursuant to this Section 1.12, and compliance with this Section 1.12 shall be the exclusive means for a stockholder to make nominations or submit other business (other than, as provided in Section 1.12(d), business other than nominations brought
8

Table of Contents
properly under and in compliance with Rule 14a-8 of the Exchange Act, as may be amended from time to time). Nothing in this Section 1.12 shall be deemed to affect any rights of the holders of any series of Preferred Stock to elect directors pursuant to any applicable provisions of the Certificate of Incorporation.
Section 1.13 Remote Communication. If authorized by the Board of Directors in its sole discretion, and subject to such guidelines and procedures as the Board of Directors may adopt, stockholders and proxyholders not physically present at a meeting of stockholders may, by means of remote communication: (a) participate in a meeting of stockholders; and (b) be deemed present in person and vote at a meeting of stockholders whether such meeting is to be held at a designated place or solely by means of remote communication; provided, that (i) the Corporation shall implement reasonable measures to verify that each person deemed present and permitted to vote at the meeting by means of remote communication is a stockholder or proxyholder; (ii) the Corporation shall implement reasonable measures to provide such stockholders and proxyholders a reasonable opportunity to participate in the meeting and to vote on matters submitted to the stockholders, including an opportunity to read or hear the proceedings of the meeting substantially concurrently with such proceedings; and (iii) if any stockholder or proxyholder votes or takes other action at the meeting by means of remote communication, a record of such vote or other action shall be maintained by the Corporation.
Section 1.14 Inspectors of Elections; Opening and Closing the Polls. (a) The Board of Directors by resolution may, and when required by law, shall, appoint one or more inspectors, which inspector or inspectors may include individuals who serve the Corporation in other capacities, including, without limitation, as officers, employees, agents or representatives, to act at the meeting of stockholders or any adjournment thereof and make a written report thereof. One or more persons may be designated as alternate inspectors to replace any inspector who fails to act. If no inspector or alternate has been appointed to act or is able to act at a meeting of stockholders and the appointment of an inspector is required by law, the chairman of the meeting shall appoint one or more inspectors to act at the meeting. Each inspector, before discharging his or her duties, shall take and sign an oath to execute faithfully the duties of inspector with strict impartiality and according to the best of his or her ability. The inspectors shall have the duties prescribed by law. The chairman of the meeting shall fix and announce at the meeting the date and time of the opening and the closing of the polls for each matter upon which the stockholders will vote at a meeting.
Section 1.15 Conduct of Business. The Chairman of the Board, or if he or she is not present, the Chief Executive Officer, or if he or she is not present, the most senior officer of the Corporation present thereat, shall conduct the meetings of stockholders. The Secretary, if present, shall act as secretary of such meetings, or if he or she is not present, then a secretary appointed by the chairman of the meeting shall act as secretary of the meeting. The Board of Directors may adopt by resolution such rules and regulations for the conduct of the meeting of stockholders as it shall deem appropriate. Except to the extent inconsistent with such rules and regulations as adopted by the Board of Directors, the chairman of the meeting of stockholders shall have the right and authority to convene and (for any or no reason) to recess and/or adjourn the meeting, to prescribe such rules, regulations and procedures and to do all such acts as, in the
9

Table of Contents
judgment of such chairman of the meeting, are appropriate for the proper conduct of the meeting. Such rules, regulations or procedures, whether adopted by the Board or prescribed by the chairman of the meeting, may include, without limitation, the following: (a) the establishment of an agenda or order of business for the meeting; (b) rules and procedures for maintaining order at the meeting and the safety of those present; (c) limitations on attendance at or participation in the meeting of stockholders to stockholders of record entitled to vote at the meeting, their duly authorized and constituted proxies and such other persons as the chairman of the meeting or the Board shall determine, (d) restrictions on entry to the meeting after the time fixed for commencement thereof and (e) limitations on the amount of time allotted to questions or comments by participants. If any person in attendance shall become unruly or obstruct the meeting proceedings, the chairman of the meeting shall have the power to have such person removed from the meeting. Notwithstanding anything in the Bylaws to the contrary, no business shall be conducted at a meeting except in accordance with the procedures set forth in this ARTICLE I. The chairman of the meeting of stockholders, in addition to making any other determinations that may be appropriate to the conduct of the meeting, shall, if the facts warrant, determine and declare to the meeting that any proposed item of business was not brought before the meeting in accordance with the provisions of this ARTICLE I and shall so declare to the meeting, and any such business not properly brought before the meeting shall not be transacted. Unless and to the extent determined by the Board of Directors or the chairman of the meeting, meetings of stockholders shall not be required to be held in accordance with the rules of parliamentary procedure.
Section 1.16 Stock List. A complete list of stockholders entitled to vote at any meeting of stockholders (provided, however, if the record date for determining the stockholders entitled to vote is less than ten (10) days before the date of the meeting, the list shall reflect the stockholders entitled to vote as of the tenth day before the meeting date), arranged in alphabetical order for each class of stock and showing the address of each such stockholder and the number of shares registered in the name of such stockholder, shall be open to the examination of any stockholder, for any purpose germane to the meeting, for a period of at least ten (10) days prior to the meeting, either on a reasonably accessible electronic network, provided that the information required to gain access to the list is provided with the notice of the meeting, or during ordinary business hours, at the principal place of business of the Corporation. The stock ledger of the Corporation shall be the only evidence as to who are the stockholders entitled by this section to examine the list required by this section or to vote in person or by proxy at any meeting of the stockholders.
ARTICLE II: DIRECTORS
Section 2.1 Number of Directors. The authorized number of directors of the Corporation shall be fixed by or in the manner provided in the Certificate of Incorporation.
Section 2.2 Election, Qualification and Term of Office of Directors. Directors shall be elected for such terms and in the manner provided by the Certificate of Incorporation and the General Corporation Law. Each director shall hold office until such director’s successor is duly elected and qualified, or until such director’s earlier death, resignation, removal, retirement or
10

Table of Contents
disqualification. Any director may resign at any time upon written notice to the attention of the Secretary of the Corporation. For purposes hereof, a notice given by electronic mail shall be deemed a written notice. The acceptance of the resignation shall not be necessary to make it effective. Any vacancy in the Board of Directors resulting from the death, resignation, removal, retirement or disqualification of any director or for any other reason, and any newly created directorship resulting from any increase in the authorized number of directors, shall be filled in the manner provided by the Certificate of Incorporation.
Section 2.3 Regular Meetings. Regular meetings of the Board of Directors may be held at such places, within or outside of the State of Delaware, and at such dates and times as the Chairman of the Board, the Chief Executive Officer, the Secretary or the Board of Directors may from time to time determine. Notice of regular meetings need not be given if the date, times and places thereof are fixed by resolution of the Board of Directors.
Section 2.4 Special Meetings. Special meetings of the Board of Directors may be called by the Chairman of the Board, the Chief Executive Officer, the Secretary or the Board of Directors and may be held at any time, date or place, within or outside of the State of Delaware, as the person or persons calling the meeting shall fix. Notice of the time, date and place of such meeting will be given, orally, in writing or by electronic transmission (including electronic mail), by the person or persons calling the meeting or the Secretary to all directors at least four (4) days before the meeting if the notice is mailed, or at least twenty-four (24) hours before the meeting if such notice is given by telephone, hand delivery, facsimile, electronic mail or other means of electronic transmission. Unless otherwise indicated in the notice, any and all business may be transacted at a special meeting.
Section 2.5 Remote Meetings Permitted. Members of the Board of Directors, or any committee of the Board of Directors, may participate in a meeting of the Board of Directors or such committee by means of conference telephone or other communications equipment by means of which all persons participating in the meeting can hear each other, and participation in a meeting pursuant to conference telephone or other communications equipment will constitute presence in person at such meeting.
Section 2.6 Quorum. At all meetings of the Board of Directors, a majority of the Whole Board shall constitute a quorum for the transaction of business and the act of a majority of the directors present at any meeting at which there is a quorum shall be the act of the Board of Directors, except as may be otherwise specifically provided by the General Corporation Law or by the Certificate of Incorporation. If a quorum is not present at any meeting of the Board of Directors, then the directors present thereat may adjourn the meeting from time to time, without notice other than announcement at the meeting, until a quorum is present.
Section 2.7 Board Action By Written Consent Without A Meeting. Unless otherwise restricted by the Certificate of Incorporation or these Bylaws, any action required or permitted to be taken at any meeting of the Board of Directors, or of any committee thereof, may be taken without a meeting if all members of the Board of Directors or the committee, as the case may be, consent thereto in writing or by electronic transmission and the writing or writings or electronic
11

Table of Contents
transmission or transmissions are filed with the minutes of proceedings of the Board of Directors or committee.
Section 2.8 Powers. Except as otherwise provided by the Certificate of Incorporation or the General Corporation Law, the business and affairs of the Corporation shall be managed by or under the direction of the Board of Directors.
Section 2.9 Fees and Compensation of Directors. Unless otherwise restricted by the Certificate of Incorporation or these Bylaws, the Board of Directors shall have the authority to fix the compensation of directors. No such compensation shall preclude any director from serving the Corporation in any other capacity and receiving compensation therefore.
ARTICLE III: COMMITTEES
Section 3.1 Committees of Directors. The Board of Directors may designate one or more committees, each committee to consist of one or more of the directors of the Corporation. The Board may designate one or more directors as alternate members of any committee, who may replace any absent or disqualified member at any meeting of the committee. In the absence or disqualification of a member of a committee, the member or members present at any meeting and not disqualified from voting, whether or not such member or members constitute a quorum, may unanimously appoint another member of the Board of Directors to act at the meeting in the place of any such absent or disqualified member. Any such committee, to the extent provided in the resolution of the Board of Directors, or in these Bylaws, shall have and may exercise all the powers and authority of the Board of Directors in the management of the business and affairs of the Corporation, and may authorize the seal of the Corporation to be affixed to all papers that may require it, to the extent so authorized by the Board of Directors. Unless the Board of Directors provides otherwise, at all meetings of such committee, a majority of the then‑authorized members of the committee shall constitute a quorum for the transaction of business, and the vote of a majority of the members of the committee present at any meeting at which there is a quorum shall be the act of the committee.
Section 3.2 Committee Minutes. Each committee shall keep regular minutes of its meetings and, except as otherwise provided in the resolutions of the Board of Directors establishing such committee, will report the same to the Board of Directors as requested by the Board of Directors or as otherwise required.
Section 3.3 Meetings and Actions of Committees. Unless the Board of Directors otherwise provides, each committee designated by the Board of Directors may make, alter and repeal rules for the conduct of its business. In the absence of such rules each committee will conduct its business in the same manner as the Board of Directors conducts its business pursuant to Article II of these Bylaws.
ARTICLE IV: OFFICERS
12

Table of Contents
Section 4.1 Officers. The officers of the Corporation may consist of a Chief Executive Officer, a President, a Chief Financial Officer, one or more Vice Presidents, a Secretary, a Treasurer, and such other officers, including a Controller, one or more Assistant Treasurers and one or more Assistant Secretaries, as may from time to time be appointed by the Board of Directors. All officers will be elected by the Board of Directors. Each officer will hold office until such person’s successor is elected and qualified or until such person’s earlier resignation, death or removal. Any number of offices may be held by the same person. Should any vacancy occur among the officers, the position shall be filled for the unexpired portion of the term by appointment made by the Board of Directors.
Section 4.2 Removal and Resignation of Officers. Any officer may be removed, either with or without cause, by the Board of Directors at any regular or special meeting of the Board of Directors. Such removal shall be without prejudice to the contractual rights of such officer, if any, with the Corporation.
Section 4.3 Chief Executive Officer. Subject to such supervisory powers, if any, as may be given by the Board of Directors to the Chairman of the Board, if any, the Chief Executive Officer of the Corporation shall, subject to the control of the Board of Directors, have general supervision, direction, and control of the business and the officers of the Corporation. He or she shall preside at all meetings of the stockholders and, in the absence or nonexistence of a Chairman of the Board, at all meetings of the Board of Directors and shall have the general powers and duties of management usually vested in the office of Chairman of the Board and shall have such other powers and duties as may be prescribed by the Board of Directors or these Bylaws.
Section 4.4 President. The Board of Directors shall designate a person to be President. If the Board of Directors has not designated any person to be President, then the Chief Executive Officer shall be the President. Subject to the provisions of these Bylaws and to the direction of the Board of Directors, and subject to the supervisory powers of the Chief Executive Officer (if the Chief Executive Officer is not then serving in the office of the President), and subject to such supervisory powers and authority as may be given by the Board of Directors to the Chairman of the Board, the President will have the responsibility for the general management the control of the business and affairs of the Corporation and the general supervision and direction of subordinate officers, employees and agents of the Corporation, including the power to sign certificates representing shares of capital stock of the Corporation, and will perform all duties and have all powers that are commonly incident to the office of President or that are delegated to the President by the Board of Directors.
Section 4.5 Vice Presidents. Each Vice President will have all such powers and duties as are commonly incident to the office of Vice President, including the power to sign certificates representing shares of capital stock of the Corporation, or that are delegated to him or her by the Board of Directors or the Chief Executive Officer. For the avoidance of doubt, the term Vice President shall refer to an officer elected by the Board as Vice President and shall not include any employees of the Corporation whose employment title is “Vice President” unless such
13

Table of Contents
individual has been elected by the Board of Directors as a Vice President of the Corporation in accordance with these Bylaws.
Section 4.6 Secretary. The Secretary will issue or cause to be issued all authorized notices for, and will keep, or cause to be kept, minutes of all meetings of the stockholders and of the Board of Directors. The Secretary will have charge of the corporate minute books and similar records and will perform such other duties and have such other powers as are commonly incident to the office of Secretary, including the power to sign certificates representing shares of capital stock of the Corporation, or as the Board of Directors or the Chief Executive Officer may from time to time prescribe.
Section 4.7 Chief Financial Officer. Subject to the direction of the Board of Directors and the Chief Executive Officer, the Chief Financial Officer will perform all duties and have all powers that are commonly incident to the office of Chief Financial Officer. The Chief Financial Officer shall keep and maintain, or cause to be kept and maintained, adequate and correct books and records of accounts of the properties and business transactions of the Corporation, including accounts of its assets, liabilities, receipts, disbursements, gains, losses, capital, retained earnings, and shares.
The Chief Financial Officer shall deposit or cause to be deposited all moneys and other valuables in the name and to the credit of the Corporation with such depositories as may be designated by the Board of Directors. He or she shall disburse or cause to be disbursed the funds of the Corporation as may be ordered by the Board of Directors, shall render to the President, the Chief Executive Officer, or the directors, upon request, an account of all his or her transactions as Chief Financial Officer and of the financial condition of the Corporation. The person holding the office of Chief Financial Officer will be the Treasurer of the Corporation unless the Board of Directors designates another officer as Treasurer.
Section 4.8 Authority and Duties of Officers. In addition to the foregoing authority and duties, all officers of the Corporation shall respectively have such authority and perform such duties in the management of the business of the Corporation as may be designated from time to time by the Board of Directors.
Section 4.9 Duties of Officers May be Delegated. In case any officer is absent, or for any other reason that the Board of Directors may deem sufficient, the Board of Directors may delegate from time to time the powers or duties of such officer to any other officer.
ARTICLE V: INDEMNIFICATION OF DIRECTORS AND OTHER PARTIES
Section 5.1 Indemnification of Directors and Officers. The Corporation shall, to the maximum extent and in the manner permitted by the General Corporation Law, indemnify any person who was or is a party or is threatened to be made a party to any threatened, pending or complete action, suit or proceeding, whether civil, criminal, administrative or investigative against expenses (including attorneys’ fees), judgments, fines, settlements and other amounts actually and reasonably incurred in connection with any action, suit or proceeding, arising by
14

Table of Contents
reason of the fact that such person is or was director or officer of the Corporation or, while serving as a director or officer of the Corporation, is or was serving at the request of the Corporation as a director or officer of another corporation, partnership, joint venture, trust or other enterprise; provided that, except as set forth in Section 5.7 below with respect to proceedings by any such person to enforce such person’s rights to indemnification hereunder, the Corporation shall indemnify such person in connection with a proceeding (or part thereof) initiated by such person only if such proceeding (or part thereof) was authorized by the Board of Directors.
Section 5.2 Indemnification of Others. The Corporation shall have the power, to the maximum extent and in the manner permitted by the General Corporation Law, to indemnify any person who is or was an employee or agent of the Corporation, or any other person who is or was serving at the request of the Corporation as an officer, director, employee or agent of another corporation, partnership, joint venture, trust or other enterprise.
Section 5.3 Payment of Expenses in Advance. Expenses incurred in defending any action, suit or proceeding for which indemnification is required pursuant to Section 5.1 or for which indemnification is permitted pursuant to Section 5.2 following authorization thereof by the Board of Directors shall be paid by the Corporation in advance of the final disposition of such action, suit or proceeding upon receipt of an undertaking by or on behalf of the indemnified party to repay such amount if it shall ultimately be determined that the indemnified party is not entitled to be indemnified as authorized in this Article V.
Section 5.4 Indemnity Not Exclusive. The indemnification provided by this Article V shall not be deemed exclusive of any other rights to which those seeking indemnification may be entitled under the General Corporation Law, any agreement, vote of shareholders or disinterested directors or otherwise, both as to action in an official capacity and as to action in another capacity while holding such office.
Notwithstanding the foregoing, the indemnification provided by this Article V may be limited by any exclusions or limitations in coverage that are made in any indemnification agreement or agreement containing similar terms between the indemnified party and the Corporation. Such exclusions or limitations shall not be inferred, but must be set forth explicitly in the language of such agreement, in such a way that it is clear that they apply not only to the agreement but to these Bylaws or generally to such indemnification obligations as may be in place.
Section 5.5 Insurance. The Corporation may purchase and maintain insurance on behalf of any person who is or was a director, officer, employee or agent of the Corporation, or is or was serving at the request of the Corporation as a director, officer, employee or agent of another corporation, partnership, joint venture, trust or other enterprise against any liability asserted against him or her and incurred by him or her in any such capacity, or arising out of his or her status as such, whether or, not the Corporation would have the power to indemnify him or her against such liability under the provisions of the General Corporation Law. The failure of the
15

Table of Contents
Corporation to provide insurance, or the denial of coverage by the applicable insurance company, shall not limit the Corporation’s obligations under Sections 5.1 through 5.4 of these Bylaws.
Section 5.6 Conflicts. No indemnification shall be made under this Article V, except where such indemnification is mandated by law or the order, judgment or decree of any court of competent jurisdiction, in any circumstance where it appears:
(a) That it would be inconsistent with a provision of the Certificate of Incorporation, these Bylaws, a resolution of the stockholders or an agreement in effect at the time of the accrual of the alleged cause of the action asserted in the proceeding in which the expenses were incurred or other amounts were paid, which prohibits or otherwise limits indemnification; or
(b) That it would be inconsistent with any condition expressly imposed by a court in approving a settlement.
Section 5.7 Right to Bring Suit. If (i) a claim under Section 5.1 (or, in the case where indemnification shall have been authorized thereunder, Section 5.2) is not paid in full by the Corporation within sixty (60) days after a written claim therefor has been received by the Corporation, or (ii) a claim under Section 5.3 is not paid in full within twenty (20) days after a written claim therefor has been received by the Corporation, the person entitled to such indemnification or advancement of expenses may at any time thereafter (but not before) bring suit against the Corporation to recover the unpaid amount of the claim. If successful in whole or in part in any such suit, or in a suit brought by the Corporation to recover an advancement of expenses pursuant to the terms of an undertaking, such person shall be entitled to be paid also the expense of prosecuting or defending such suit. In (x) any suit brought by such person to enforce a right to indemnification hereunder (but not in a suit brought by such person to enforce a right to an advancement of expenses) it shall be a defense that, and (y) in any suit brought by the Corporation to recover an advancement of expenses pursuant to the terms of an undertaking, the Corporation shall be entitled to recover such expenses upon a final adjudication provided that, such person has not met any applicable standard of conduct necessary to demonstrate entitlement to indemnification. Neither the failure of the Corporation (including its directors who are not parties to such action, a committee of such directors, independent legal counsel, or its stockholders) to have made a determination that indemnification of such person is proper in the circumstances because such person has met the applicable standard of conduct necessary to demonstrate entitlement to indemnification hereunder, nor an actual determination by the Corporation (including its directors who are not parties to such action, a committee of such directors, independent legal counsel, or its stockholders) that such person has not met the applicable standard of conduct, shall create a presumption that such person has not met the applicable standard of conduct or, in the case of such a suit brought by such person, be a defense to such suit. In any suit brought by any such person to enforce a right of indemnification or to an advancement of expenses hereunder, or brought by the Corporation to recover an advancement of expenses pursuant to the terms of an undertaking, the burden of proving that the person seeking such right is not entitled to be indemnified, or to such advancement of expenses, under this Article V or otherwise shall be on the Corporation.
16

Table of Contents
Section 5.8 Amendment of Article V. Any amendment, repeal or modification of this Article V shall not adversely affect any right or protection hereunder of any person in respect of any act or omission occurring prior to the time of such amendment, repeal or modification.
ARTICLE VI: GENERAL MATTERS
Section 6.1 Checks. From time to time, the Board of Directors shall determine by resolution which person or persons may sign or endorse all checks, drafts, other orders for payment of money, notes or other evidences of indebtedness that are issued in the name of or payable to the Corporation, and only the persons so authorized shall sign or endorse those instruments.
Section 6.2 Execution of Corporate Contracts and Instruments. The Board of Directors, except as otherwise provided in these Bylaws, may authorize any officer or officers, or agent or agents, to enter into any contract or execute any instrument in the name of and on behalf of the Corporation; such authority may be general or confined to specific instances. Unless so authorized or ratified by the Board of Directors or within the agency power of an officer, no officer, agent or employee shall have any power or authority to bind the Corporation by any contract or engagement or to pledge its credit or to render it liable for any purpose or for any amount.
Section 6.3 Stock Certificates. The shares of a Corporation shall be represented by certificates, provided that the Board of Directors of the Corporation may provide by resolution or resolutions that some or all of any or all classes or series of its stock shall be uncertificated shares. Any such resolution shall not apply to shares represented by a certificate until such certificate is surrendered to the Corporation. Notwithstanding the adoption of such a resolution by the Board of Directors, every holder of stock represented by certificates shall be entitled to have a certificate representing the number of shares registered signed by or in the name of the Corporation by the Chairman of the Board, any Vice Chairman of the Board, the President or Vice-President, and by the Treasurer or an Assistant Treasurer, or the Secretary or an Assistant Secretary of the Corporation. Any or all of the signatures on the certificate may be a facsimile. In case any officer, transfer agent or registrar who has signed or whose facsimile signature has been placed upon a certificate has ceased to be such officer, transfer agent or registrar before such certificate is issued, it may be issued by the Corporation with the same effect as if he or she were such officer, transfer agent or registrar at the date of issue.
Section 6.4 Lost Certificates. Except as provided in this Section 6.4, no new certificates or uncertificated shares shall be issued to replace a previously issued certificate unless the latter is surrendered to the Corporation and cancelled at the same time. The Corporation may issue a new stock certificate or uncertificated shares in the place of any certificate previously issued by it, alleged to have been lost, stolen or destroyed, and the Corporation may require the owner of the lost, stolen or destroyed certificate, or the owner’s legal representative, to give the Corporation a bond sufficient to indemnify it against any claim
17

Table of Contents
that may be made against it on account of the alleged loss, theft or destruction of any such certificate or the issuance of such new certificate or uncertificated shares.
Section 6.5 Fiscal Year. The fiscal year of the Corporation shall be January 1 to December 31, unless otherwise determined by resolution of the Board of Directors.
Section 6.6 Seal. The Corporation may adopt a corporate seal, which may be altered at pleasure, and may use the same by causing it or a facsimile thereof, to be impressed or affixed or in any other manner reproduced.
Section 6.7 Construction; Definitions. Unless the context requires otherwise, the general provisions, rules of construction and definitions in the General Corporation Law shall govern the construction of these Bylaws. Without limiting the generality of this provision, the singular number includes the plural, the plural number includes the singular, and the term “person” includes any natural person, corporation or other legal entity.
Section 6.8 Severability. If any provision of these Bylaws will be held to be invalid, illegal, unenforceable or in conflict with the provisions of the Certificate of Incorporation, then such provision will nonetheless be enforced to the maximum extent possible consistent with such holding and the remaining provisions of these Bylaws (including without limitation, all portions of any section of these Bylaws containing any such provision held to be invalid, illegal, unenforceable or in conflict with the Certificate of Incorporation, that are not themselves invalid, illegal, unenforceable or in conflict with the Certificate of Incorporation) will remain in full force and effect.
Section 6.9 Waiver of Notice. Whenever notice is required to be given under any provision of the General Corporation Law or of the Certificate of Incorporation or these Bylaws, a written waiver thereof, signed by the person entitled to notice, whether before or after the time stated therein, shall be deemed equivalent to notice. Attendance of a person at a meeting shall constitute a waiver of notice of such meeting, except when the person attends a meeting for the express purpose of objecting, at the beginning of the meeting, to the transaction of any business because the meeting is not lawfully called or convened. Neither the business to be transacted at, nor the purpose of, any regular or special meeting of the directors, or members of a committee of directors, need be specified in any written waiver of notice unless so required by the Certificate of Incorporation or these Bylaws.
Section 6.10 Voting of Securities. Except as the Board of Directors may otherwise designate, the Chief Executive Officer, the President, the Chief Financial Officer or the Treasurer may waive notice, vote, consent, or appoint any person or persons to waive notice, vote or consent, on behalf of the Corporation, and act as, or appoint any person or persons to act as, proxy or attorney-in-fact for the Corporation (with or without power of substitution), with respect to the securities of any other entity that may be held by the Corporation.
ARTICLE VII: AMENDMENTS
18

Table of Contents
Section 7.1 Amendments. These Bylaws may be altered, amended or repealed, in whole or in part, or new Bylaws may be adopted by the Board or by the stockholders as expressly provided in the Certificate of Incorporation.
19